@@ -203,21 +203,24 @@ def main(
 
 
 @main.command()
-@click.argument("identifier", type=int)
-@click.option("--careful", is_flag=True, help="Don't assume unique field for a given (obs, mjd, catalogid)")
-def lookup(identifier, careful, **kwargs):
-    """Lookup a target by catalog identifier or SDSS identifier."""
+@click.argument("identifiers", type=int, nargs=-1)
+@click.option("--output", "-O", default=None, type=str, help="Output file")
+def lookup(identifiers, output, **kwargs):
+    """Lookup target(s) by catalog or SDSS identifier."""
 
-    if not identifier:
+    if not identifiers:
         return
 
+    import h5py as h5
+    from contextlib import nullcontext
     from peewee import fn
     from itertools import chain, starmap
+    from almanac import io
     from almanac.database import database
-    from almanac.apogee import get_exposures
+    from almanac.apogee import get_exposures, get_almanac_data
     from sdssdb.peewee.sdss5db.targetdb import (
         Assignment, AssignmentStatus,CartonToTarget, Target, Hole, Observatory,
-        Design, DesignToField
+        Design, DesignToField, Field
     )
     from sdssdb.peewee.sdss5db.catalogdb import SDSS_ID_flat
 
@@ -225,70 +228,120 @@ def lookup(identifier, careful, **kwargs):
     from rich.console import Console
     from rich.live import Live
 
-    identifiers = (
+    sq = (
         SDSS_ID_flat
-        .select(
-            SDSS_ID_flat.catalogid,
-            SDSS_ID_flat.sdss_id,
-        )
+        .select(SDSS_ID_flat.sdss_id)
         .where(
-            (SDSS_ID_flat.sdss_id == identifier)
-        |   (SDSS_ID_flat.catalogid == identifier)
+            (SDSS_ID_flat.sdss_id.in_(identifiers))
+        |   (SDSS_ID_flat.catalogid.in_(identifiers))
         )
+        .alias("sq")
+    )
+    q = (
+        SDSS_ID_flat
+        .select(SDSS_ID_flat.catalogid, SDSS_ID_flat.sdss_id)
+        .distinct()
+        .join(sq, on=(SDSS_ID_flat.sdss_id == sq.c.sdss_id))
+        .order_by(SDSS_ID_flat.sdss_id.asc())
         .tuples()
     )
 
-    identifiers = { catalogid: sdss_id for catalogid, sdss_id in identifiers }
-    if not identifiers:
-        raise click.ClickException(f"Identifier {identifier} not found in SDSS-V database")
+    catalogids = { catalogid: sdss_id for catalogid, sdss_id in q }
+
+    if not catalogids:
+        raise click.ClickException(f"Identifiers {identifiers} not found in SDSS-V database")
+
+    # todo hacky
+    for m in (
+        Target, Observatory, AssignmentStatus, Field, CartonToTarget,
+        Assignment, Hole, Design, DesignToField
+    ):
+        try:
+            m.get()
+        except:
+            print(f"Failed {m}")
+        else:
+            print(f"Success {m}")
+
+        m._meta.schema = "targetdb"
 
     q = (
         Target
         .select(
             fn.Lower(Observatory.label),
             AssignmentStatus.mjd,
+            Field.field_id,
         )
+        .distinct()
         .join(CartonToTarget)
         .join(Assignment)
         .join(AssignmentStatus)
         .switch(Assignment)
         .join(Hole)
         .join(Observatory)
+        .switch(Assignment)
+        .join(Design)
+        .join(DesignToField)
+        .join(Field)
         .where(
-            Target.catalogid.in_(tuple(identifiers.keys()))
+            Target.catalogid.in_(tuple(catalogids.keys()))
         &   (AssignmentStatus.status == 1)
         )
         .tuples()
     )
-    q = tuple(set([(obs, int(mjd)) for obs, mjd in q]))
+    n, fields = (0, {})
+    for obs, mjd, field_id in q:
+        mjd = int(mjd)
+        fields.setdefault((obs, mjd), set())
+        fields[(obs, mjd)].add(field_id)
+        n += 1
 
     console = Console()
 
-    title = "; ".join([f"SDSS ID {sdss_id} / Catalog ID {catalogid}" for catalogid, sdss_id in identifiers.items()])
+    rich_table = RichTable(
+        title=f"Exposures\n({n} obs/mjd/field combinations)",
+        title_style="bold blue",
+        show_header=True,
+        header_style="bold cyan"
+    )
 
-    # Create Rich table
-    rich_table = RichTable(title=f"{title}", title_style="bold blue", show_header=True, header_style="bold cyan")
-
-    for field_name in ("obs", "mjd", "exposure", "field", "fiber_id", "catalogid"):
+    for field_name in ("#", "obs", "mjd", "exposure", "field", "fiber_id", "catalogid", "sdss_id"):
         rich_table.add_column(field_name, justify="center")
 
-    fields = {}
-    with Live(rich_table, console=console, refresh_per_second=4, screen=False) as live:
-        for exposure in chain(*starmap(get_exposures, q)):
-            key = (exposure.observatory, exposure.mjd)
-            if (key not in fields or fields[key] == exposure.field_id) or careful:
-                for target in exposure.targets:
-                    if target.catalogid in identifiers:
-                        fields[key] = exposure.field_id
-                        rich_table.add_row(*list(map(str, (
-                            exposure.observatory,
-                            exposure.mjd,
-                            exposure.exposure,
-                            exposure.field_id,
-                            target.fiber_id,
-                            target.catalogid
-                        ))))
-                        break
+    done = set()
+    io_kwds = dict(fibers=True, compression=False)
+    with (h5.File(output, "a") if output else nullcontext()) as fp:
+
+        i = 1
+        with Live(rich_table, console=console, refresh_per_second=4) as live:
+            for exposure in chain(*starmap(get_exposures, fields.keys())):
+                key = (exposure.observatory, exposure.mjd)
+                field_ids = fields[key]
+
+                if output and key not in done:
+                    done.add(key)
+                    r = get_almanac_data(*key, fibers=True, meta=True)
+                    io.update(fp, *r, **io_kwds)
+
+                if exposure.field_id in field_ids:
+                    for target in exposure.targets:
+                        if target.catalogid in catalogids:
+                            rich_table.add_row(*list(map(str, (
+                                i,
+                                exposure.observatory,
+                                exposure.mjd,
+                                exposure.exposure,
+                                exposure.field_id,
+                                target.fiber_id,
+                                target.catalogid,
+                                catalogids[target.catalogid],
+                            ))))
+                            i += 1
+                            break
+    if output:
+        console.print(f"Updated {output_path} with:")
+        for obs, mjd in done:
+            console.print(f"  - {obs}/{mjd}")
 
 @main.group()
 def add(**kwargs):
