@@ -66,7 +66,7 @@ class Exposure(BaseModel):
 
     @computed_field(description="Whether this exposure is from the FPS era")
     def fps(self) -> bool:
-        start = dict(apo=59423, lco=59810)[self.observatory]
+        start = dict(apo=59423, lco=59809)[self.observatory]
         return self.mjd >= start
 
     #@computed_field(description="FPI")
@@ -332,7 +332,6 @@ class Exposure(BaseModel):
                             "deccat": np.nan,
                             "category": "bonus",
                         })
-                    rows.sort("fiberId")
                 else:
                     factory = PlateTarget
                     bad_exposure_notes = (
@@ -349,6 +348,11 @@ class Exposure(BaseModel):
                             # went wrong in early plate era.
                             rows["plugged_mjd"] = self.plugged_mjd
                             rows["observatory"] = self.observatory
+                try:
+                    rows.sort("fiberId")
+                except:
+                    None
+
                 try:
                     self._targets = tuple([factory(**r) for r in rows])
                 except Exception as e:
